==> live-usb-maker-gui-antix_0.1.10.tar.xz: live-usb-maker-gui-antix/translations/live-usb-maker-gui-antix_es.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="es" version="2.1">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="mainwindow.ui" line="14"/>
        <source>Program_Name</source>
        <translation>Nombre_Programa</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="33"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Select Target USB Device&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Seleccione Dispositivo USB Destino&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="43"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Select ISO file&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Seleccione fichero ISO&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="88"/>
        <location filename="mainwindow.cpp" line="446"/>
        <location filename="mainwindow.cpp" line="464"/>
        <source>Select ISO</source>
        <translation>Seleccione ISO</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="100"/>
        <source>Refresh drive list</source>
        <translation>Refrescar lista de dispositivos</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="112"/>
        <location filename="mainwindow.cpp" line="393"/>
        <location filename="mainwindow.cpp" line="399"/>
        <source>Show advanced options</source>
        <translation>Muestra opciones avanzadas</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="130"/>
        <source>Advanced Options</source>
        <translation>Opciones avanzadas</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="139"/>
        <source>Verbosity (less to more):</source>
        <translation>Verbosidad (less a more)</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="190"/>
        <source>Size of ESP (uefi) partition:</source>
        <translation>Tamaño del partición ESP (uefi):</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="222"/>
        <source>Make the ext4 filesystem even if one exists</source>
        <translation>Haga el sistema de ficheros de ext4 aunque existe</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="229"/>
        <source>Save the original boot directory when updating a live-usb</source>
        <translation>Guarda la carpeta original de inicio cuando actualizando un live-usb</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="236"/>
        <source>Use gpt partitioning instead of msdos</source>
        <translation>Usa particionamiento gpt en vez de msdos</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="239"/>
        <source>GPT partitioning</source>
        <translation>Particionamiento GPT</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="246"/>
        <source>Update (only update an existing live-usb)</source>
        <translation>Actualiza (solamente actualiza un liveUSB existente)</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="253"/>
        <source>Don&apos;t replace syslinux files</source>
        <translation>No reemplazar ficheros syslinux</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="256"/>
        <source>Keep syslinux files</source>
        <translation>Mantenga ficheros syslinux</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="263"/>
        <source>Ignore USB/removable check</source>
        <translation>Ignorar chequeo USB/removible</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="270"/>
        <source>Temporarily disable automounting</source>
        <translation>Temporalmente deshabilitar automontaje</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="280"/>
        <source>Set pmbr_boot disk flag (won&apos;t boot via UEFI)</source>
        <translation>Fijar bandera disco a pmbr_boot (no iniciar via UEFI)</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="293"/>
        <source>Options</source>
        <translation>Opciones</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="308"/>
        <source>Don&apos;t run commands that affect the usb device</source>
        <translation>No ejecuta comandos que afecta el dispositivo USB</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="311"/>
        <source>Dry run (no change to system)</source>
        <translation>Modo simulación (ningun cambio al sistema)</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="318"/>
        <source>clone from a mounted live-usb or iso-file.</source>
        <translation>clonar de un liveUSB montado o un fichero ISO.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="321"/>
        <source>Clone an existing live system</source>
        <translation>Clonar un sistema en vivo existente</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="328"/>
        <source>Set up to boot from an encrypted partition, will prompt for pass phrase on first boot</source>
        <translation>Configurar para iniciar desde partición cifrado, se pregunta para frase de pase en el primer arranque</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="331"/>
        <source>Encrypt</source>
        <translation>Cifrar</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="338"/>
        <source>Clone running live system</source>
        <translation>Un sistema clonada ejecutando en vivo</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="345"/>
        <source>Read-only, cannot be used with persistency</source>
        <translation>Leer solamente, no soporta persistencía</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="348"/>
        <source>Copy image to USB (dd)</source>
        <translation>Copiar imagen a USB (con dd)</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="371"/>
        <source>Percent of USB-device to use:</source>
        <translation>Porciento del dispositivo USB a utilizar:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="394"/>
        <source>Label ext partition:</source>
        <translation>Rotula para partición ext:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="442"/>
        <source>For distros other than antiX/MX use &quot;Copy image to USB (dd)&quot; only.</source>
        <translation>Para distros otro que antiX/MX utiliza solamente, &quot;Copiar imagen a USB (dd)&quot;</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="499"/>
        <source>Quit application</source>
        <translation>Terminar aplicación</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="502"/>
        <source>Close</source>
        <translation>Cerrar</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="510"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="542"/>
        <source>Display help </source>
        <translation>Mostrar la ayuda</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="545"/>
        <source>Help</source>
        <translation>Ayuda</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="553"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="569"/>
        <source>Back</source>
        <translation>Anterior</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="628"/>
        <source>Next</source>
        <translation>Próximo</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="655"/>
        <source>About this application</source>
        <translation>Acerca de esta aplicación</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="658"/>
        <source>About...</source>
        <translation>Acerca de...</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="666"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="72"/>
        <location filename="mainwindow.cpp" line="239"/>
        <location filename="mainwindow.cpp" line="379"/>
        <source>Failure</source>
        <translation>Falla</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="72"/>
        <source>Source and destination are on the same device, please select again.</source>
        <translation>Fuente y destinación en el mismo dispositivo, seleccionar de nuevo.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="94"/>
        <source>Writing %1 using 'dd' command to /dev/%2,

Please wait until the the process is completed</source>
        <translation>Escribiendo %1 con el comando &apos;dd&apos; hacia /dev/%2,

Favor espere hasta que el proceso completa.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="237"/>
        <source>Success</source>
        <translation>Exito</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="237"/>
        <source>LiveUSB creation successful!</source>
        <translation>¡Creación del LiveUSB exitosa!</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="239"/>
        <source>Error encountered in the LiveUSB creation process</source>
        <translation>Encontro error en proceso de creación del LiveUSB</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="285"/>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="285"/>
        <source>Please select a USB device to write to</source>
        <translation>Favor seleccione dispositivo USB a donde escribir</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="288"/>
        <location filename="mainwindow.cpp" line="458"/>
        <source>clone</source>
        <translation>clonar</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="327"/>
        <source>About</source>
        <translation>Acerca de</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="328"/>
        <source>Version: </source>
        <translation>Versión:</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="329"/>
        <source>Program for creating a live-usb from an iso-file, another live-usb, a live-cd/dvd, or a running live system.</source>
        <translation>Programa para crear liveUSB desde un fichero ISO, otro liveUSB, liveCD/DVD, o un sistema actualmente ejecutando.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="331"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="332"/>
        <location filename="mainwindow.cpp" line="338"/>
        <source>License</source>
        <translation>Licencia</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="333"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="368"/>
        <source>Select an ISO file to write to the USB drive</source>
        <translation>Seleccione fichero ISO para escribir al USB</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="374"/>
        <location filename="mainwindow.cpp" line="442"/>
        <source>Select Source Directory</source>
        <translation>Seleccione Carpeta Fuente</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="379"/>
        <source>Could not find %1/antiX/linuxfs file</source>
        <translation>No encontro %1/antiX/linuxfs fichero</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="395"/>
        <source>Hide advanced options</source>
        <translation>Esconde opciones avanzadas</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="441"/>
        <location filename="mainwindow.cpp" line="456"/>
        <source>Select Source</source>
        <translation>Seleccione Fuente</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="445"/>
        <location filename="mainwindow.cpp" line="462"/>
        <source>Select ISO file</source>
        <translation>Seleccione fichero ISO</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="main.cpp" line="52"/>
        <source>You must run this program as root.</source>
        <translation>Debe ejecutar este programa como root.</translation>
    </message>
</context>
</TS>

==> live-usb-maker-gui-antix_0.2.17.tar.xz: live-usb-maker-gui-antix/translations/live-usb-maker-gui-antix_es.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="es" version="2.1">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="mainwindow.ui" line="14"/>
        <source>Program_Name</source>
        <translation>Nombre_Programa</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="46"/>
        <source>Quit application</source>
        <translation>Terminar aplicación</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="49"/>
        <source>Close</source>
        <translation>Cerrar</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="56"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="88"/>
        <source>Display help </source>
        <translation>Mostrar la ayuda</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="91"/>
        <source>Help</source>
        <translation>Ayuda</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="98"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="114"/>
        <source>Back</source>
        <translation>Anterior</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="172"/>
        <source>Next</source>
        <translation>Próximo</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="198"/>
        <source>About this application</source>
        <translation>Acerca de esta aplicación</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="201"/>
        <source>About...</source>
        <translation>Acerca de...</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="208"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="239"/>
        <location filename="mainwindow.cpp" line="462"/>
        <location filename="mainwindow.cpp" line="481"/>
        <source>Select ISO</source>
        <translation>Seleccione ISO</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="250"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Select Target USB Device&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Seleccione Dispositivo USB Destino&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="260"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Select ISO file&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Seleccione fichero ISO&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="289"/>
        <source>Advanced Options</source>
        <translation>Opciones avanzadas</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="307"/>
        <source>Make the ext4 filesystem even if one exists</source>
        <translation>Haga el sistema de ficheros de ext4 aunque existe</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="314"/>
        <source>Save the original boot directory when updating a live-usb</source>
        <translation>Guarda la carpeta original de inicio cuando actualizando un live-usb</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="321"/>
        <source>Use gpt partitioning instead of msdos</source>
        <translation>Usa particionamiento gpt en vez de msdos</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="324"/>
        <source>GPT partitioning</source>
        <translation>Particionamiento GPT</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="331"/>
        <source>Update (only update an existing live-usb)</source>
        <translation>Actualiza (solamente actualiza un liveUSB existente)</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="338"/>
        <source>Don&apos;t replace syslinux files</source>
        <translation>No reemplazar ficheros syslinux</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="341"/>
        <source>Keep syslinux files</source>
        <translation>Mantenga ficheros syslinux</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="348"/>
        <source>Ignore USB/removable check</source>
        <translation>Ignorar chequeo USB/removible</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="355"/>
        <source>Temporarily disable automounting</source>
        <translation>Temporalmente deshabilitar automontaje</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="365"/>
        <source>Set pmbr_boot disk flag (won&apos;t boot via UEFI)</source>
        <translation>Fijar bandera disco a pmbr_boot (no iniciar via UEFI)</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="372"/>
        <source>Don&apos;t use fuseiso to mount iso files</source>
        <translation>No use fuseiso para montar archivos iso</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="398"/>
        <source>Size of ESP (uefi) partition:</source>
        <translation>Tamaño del partición ESP (uefi):</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="418"/>
        <source>Verbosity (less to more):</source>
        <translation>Verbosidad (less a more)</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="457"/>
        <source>vfat</source>
        <translation>vfat</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="462"/>
        <source>exfat</source>
        <translation>exfat</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="467"/>
        <source>ext4</source>
        <translation>ext4</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="472"/>
        <source>ntfs</source>
        <translation>ntfs</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="493"/>
        <source>Make separate data partition (percent)</source>
        <translation>Crear una partición de datos separada (porcentaje)</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="500"/>
        <source>Format</source>
        <translation>Formatear</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="510"/>
        <source>Refresh drive list</source>
        <translation>Refrescar lista de dispositivos</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="524"/>
        <location filename="mainwindow.cpp" line="407"/>
        <source>Show advanced options</source>
        <translation>Muestra opciones avanzadas</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="544"/>
        <source>Mode</source>
        <translation>Modo</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="559"/>
        <source>Full-featured mode - writable LiveUSB</source>
        <translation>Modo de funciones completas - LiveUSB escribible</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="569"/>
        <source>Read-only, cannot be used with persistency</source>
        <translation>Leer solamente, no soporta persistencía</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="572"/>
        <source>Image mode - read-only LiveUSB (dd)</source>
        <translation>Modo imagen - LiveUSB solo escribible (dd)</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="586"/>
        <source>For distros other than antiX/MX use image mode (dd).</source>
        <translation>Para distros no antiX/MX utilizar el modo imagen (dd).</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="634"/>
        <source>Options</source>
        <translation>Opciones</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="669"/>
        <source>Percent of USB-device to use:</source>
        <translation>Porciento del dispositivo USB a utilizar:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="676"/>
        <source>Label ext partition:</source>
        <translation>Rotula para partición ext:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="724"/>
        <source>Don&apos;t run commands that affect the usb device</source>
        <translation>No ejecuta comandos que afecta el dispositivo USB</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="727"/>
        <source>Dry run (no change to system)</source>
        <translation>Modo simulación (ningun cambio al sistema)</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="734"/>
        <source>clone from a mounted live-usb or iso-file.</source>
        <translation>clonar de un liveUSB montado o un fichero ISO.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="737"/>
        <source>Clone an existing live system</source>
        <translation>Clonar un sistema en vivo existente</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="744"/>
        <source>Set up to boot from an encrypted partition, will prompt for pass phrase on first boot</source>
        <translation>Configurar para iniciar desde partición cifrado, se pregunta para frase de pase en el primer arranque</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="747"/>
        <source>Encrypt</source>
        <translation>Cifrar</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="754"/>
        <source>Clone running live system</source>
        <translation>Un sistema clonada ejecutando en vivo</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="86"/>
        <location filename="mainwindow.cpp" line="267"/>
        <location filename="mainwindow.cpp" line="392"/>
        <source>Failure</source>
        <translation>Falla</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="86"/>
        <source>Source and destination are on the same device, please select again.</source>
        <translation>Fuente y destinación en el mismo dispositivo, seleccionar de nuevo.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="111"/>
        <source>Writing %1 using 'dd' command to /dev/%2,

Please wait until the the process is completed</source>
        <translation>Escribiendo %1 con el comando &apos;dd&apos; hacia /dev/%2,

Favor espere hasta que el proceso completa.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="265"/>
        <source>Success</source>
        <translation>Exito</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="265"/>
        <source>LiveUSB creation successful!</source>
        <translation>¡Creación del LiveUSB exitosa!</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="267"/>
        <source>Error encountered in the LiveUSB creation process</source>
        <translation>Encontro error en proceso de creación del LiveUSB</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="316"/>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="316"/>
        <source>Please select a USB device to write to</source>
        <translation>Favor seleccione dispositivo USB a donde escribir</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="319"/>
        <location filename="mainwindow.cpp" line="475"/>
        <source>clone</source>
        <translation>clonar</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="355"/>
        <source>About %1</source>
        <translation>Acerca de %1</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="356"/>
        <source>Version: </source>
        <translation>Versión:</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="357"/>
        <source>Program for creating a live-usb from an iso-file, another live-usb, a live-cd/dvd, or a running live system.</source>
        <translation>Programa para crear liveUSB desde un fichero ISO, otro liveUSB, liveCD/DVD, o un sistema actualmente ejecutando.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="359"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="360"/>
        <source>%1 License</source>
        <translation>%1 Licencia</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="368"/>
        <source>%1 Help</source>
        <translation>%1 Ayuda</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="379"/>
        <source>Select an ISO file to write to the USB drive</source>
        <translation>Seleccione fichero ISO para escribir al USB</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="387"/>
        <location filename="mainwindow.cpp" line="458"/>
        <source>Select Source Directory</source>
        <translation>Seleccione Carpeta Fuente</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="392"/>
        <source>Could not find %1/antiX/linuxfs file</source>
        <translation>No encontro %1/antiX/linuxfs fichero</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="413"/>
        <source>Hide advanced options</source>
        <translation>Esconde opciones avanzadas</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="457"/>
        <location filename="mainwindow.cpp" line="473"/>
        <source>Select Source</source>
        <translation>Seleccione Fuente</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="461"/>
        <location filename="mainwindow.cpp" line="479"/>
        <source>Select ISO file</source>
        <translation>Seleccione fichero ISO</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="about.cpp" line="32"/>
        <source>License</source>
        <translation>Licencia</translation>
    </message>
    <message>
        <location filename="about.cpp" line="33"/>
        <location filename="about.cpp" line="43"/>
        <source>Changelog</source>
        <translation>Registro de cambios</translation>
    </message>
    <message>
        <location filename="about.cpp" line="34"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="about.cpp" line="51"/>
        <source>&amp;Close</source>
        <translation>&amp;Cerrar</translation>
    </message>
    <message>
        <location filename="main.cpp" line="75"/>
        <source>You must run this program as root.</source>
        <translation>Debe ejecutar este programa como root.</translation>
    </message>
</context>
</TS>
